@@ -9,8 +9,10 @@ by, or on behalf of, User. """
 
 import json
 import pandas
+import requests
 import datetime
 from pacifico.util import Enumerations
+from pacifico_devel.util.selenium import SeleniumWebdriver
 
 
 def jsonToFormat(format, response):
@@ -35,6 +37,8 @@ def jsonToDataFrame(jsonString):
 
 def jsonReportsToDataFrame(jsonString):
     dataFrameData = []
+    firstBrowser = True
+    windowCount = 0
     data = json.loads(jsonString)
     for author in data.keys():
         for datePublication in data[author].keys():
@@ -61,6 +65,29 @@ def jsonReportsToDataFrame(jsonString):
                                             variant = reportDict['variant']
                                             variantValueType = Enumerations.ValueType.fromString(variant['type'])
                                             variantValue = variantValueType.forceType(variant['value'])
+                                            if variantValueType == Enumerations.ValueType.ValueType_Browser:
+                                                try:
+                                                    import os
+                                                    from selenium.webdriver.common.keys import Keys
+                                                    html = requests.get(variantValue).content
+                                                    wd = os.getcwd()
+                                                    filename = os.path.join(wd, 'browser.html')
+                                                    with open(filename, 'wb') as file:
+                                                        file.write(html)
+                                                    if firstBrowser:
+                                                        driver = SeleniumWebdriver.getDriver(detach=True)
+                                                        firstBrowser = False
+                                                    else:
+                                                        windowCount += 1
+                                                        tabName = str(windowCount)
+                                                        driver.execute_script(f"window.open('about:blank','{tabName}');")
+                                                        driver.switch_to.window(f"{tabName}")
+                                                    driver.get("file:" + filename)
+                                                    os.remove(filename)
+                                                except Exception as e:
+                                                    print(f"Formatting Error: Browser type values couldn't be "
+                                                          f"displayed, probably because Google Chrome is not "
+                                                          f"installed. ({str(e)})")
                                             variantValueType = variantValueType.getString()
                                             if 'dateTenor' in reportDict.keys():
                                                 if isinstance(reportDict['dateTenor'], str):
